@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _MAIN_H
@@ -71,7 +71,7 @@ typedef struct {
 } REQ;
 
 /* Global variables */
-extern thread_master *master;
+extern thread_master_t *master;
 extern REQ *req;		/* Cmd line arguments */
 
 /* Data buffer length description */
