@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <ctype.h>
@@ -32,10 +32,10 @@
 #include "parser.h"
 #include "daemon.h"
 
-int smtp_connect_thread(thread *);
+int smtp_connect_thread(thread_t *);
 
 /* module variables */
-static smtp_host *default_host = NULL;
+static smtp_host_t *default_host = NULL;
 
 /*
  * Used as a callback from free_list() to free all
@@ -54,10 +54,10 @@ smtp_free_host(void *data)
 void
 free_smtp_check(void *data)
 {
-  	smtp_checker *smtp_chk = CHECKER_DATA(data);
-	free_list(smtp_chk->host);
-	FREE(smtp_chk->helo_name);
-	FREE(smtp_chk);
+  	smtp_checker_t *smtp_checker = CHECKER_DATA(data);
+	free_list(smtp_checker->host);
+	FREE(smtp_checker->helo_name);
+	FREE(smtp_checker);
 	FREE(data);
 }
 
@@ -68,11 +68,11 @@ free_smtp_check(void *data)
 void
 smtp_dump_host(void *data)
 {
-        smtp_host *smtp_hst = data;
-        log_message(LOG_INFO, "   Checked ip = %s", inet_ntop2(smtp_hst->ip));
-        log_message(LOG_INFO, "           port = %d", ntohs(smtp_hst->port));
-	if (smtp_hst->bindto)
-        	log_message(LOG_INFO, "           bindto = %s", inet_ntop2(smtp_hst->bindto));
+        smtp_host_t *smtp_host = data;
+        log_message(LOG_INFO, "   Checked ip = %s", inet_sockaddrtos(&smtp_host->dst));
+        log_message(LOG_INFO, "           port = %d", ntohs(ntohs(inet_sockaddrport(&smtp_host->dst))));
+	if (smtp_host->bindto.ss_family)
+        	log_message(LOG_INFO, "           bindto = %s", inet_sockaddrtos(&smtp_host->bindto));
 }
 
 /* 
@@ -82,31 +82,30 @@ smtp_dump_host(void *data)
 void
 dump_smtp_check(void *data)
 {
-	smtp_checker *smtp_chk = CHECKER_DATA(data);
+	smtp_checker_t *smtp_checker = CHECKER_DATA(data);
 	log_message(LOG_INFO, "   Keepalive method = SMTP_CHECK");
-        log_message(LOG_INFO, "           helo = %s", smtp_chk->helo_name);
-        log_message(LOG_INFO, "           timeout = %ld", smtp_chk->timeout/TIMER_HZ);
-        log_message(LOG_INFO, "           retry = %d", smtp_chk->retry);
-        log_message(LOG_INFO, "           delay before retry = %ld", smtp_chk->db_retry/TIMER_HZ);
-	dump_list(smtp_chk->host);
+        log_message(LOG_INFO, "           helo = %s", smtp_checker->helo_name);
+        log_message(LOG_INFO, "           timeout = %ld", smtp_checker->timeout/TIMER_HZ);
+        log_message(LOG_INFO, "           retry = %d", smtp_checker->retry);
+        log_message(LOG_INFO, "           delay before retry = %ld", smtp_checker->db_retry/TIMER_HZ);
+	dump_list(smtp_checker->host);
 }
 
 /* Allocates a default host structure */
-smtp_host *
+smtp_host_t *
 smtp_alloc_host(void)
 {
-	checker *chk = LIST_TAIL_DATA(checkers_queue);
-	smtp_host *new;
+	smtp_host_t *new;
 
 	/* Allocate the new host data structure */
-	new = (smtp_host *)MALLOC(sizeof(smtp_host));
+	new = (smtp_host_t *)MALLOC(sizeof(smtp_host_t));
 
 	/* 
 	 * By default we set the ip to connect to as the same ip as the current real server
 	 * in the rs config. This might be overridden later on by a "connect_ip" keyword.
 	 */
-	new->ip = CHECKER_RIP(chk);
-	new->port = htons(SMTP_DEFAULT_PORT);
+	checker_set_dst(&new->dst);
+	checker_set_dst_port(&new->dst, htons(SMTP_DEFAULT_PORT));
 	return new;
 }
 
@@ -117,30 +116,30 @@ smtp_alloc_host(void)
 void
 smtp_check_handler(vector strvec)
 {
-	smtp_checker *smtp_chk = (smtp_checker *)MALLOC(sizeof(smtp_checker));
+	smtp_checker_t *smtp_checker = (smtp_checker_t *)MALLOC(sizeof(smtp_checker_t));
 
 	/* 
 	 * Set something sane for the default HELO banner
 	 * May be overridden by a "helo_name" keyword later.
 	 */
-	smtp_chk->helo_name = (char *)MALLOC(strlen(SMTP_DEFAULT_HELO) + 1);
-	memcpy(smtp_chk->helo_name, SMTP_DEFAULT_HELO, strlen(SMTP_DEFAULT_HELO) + 1);
+	smtp_checker->helo_name = (char *)MALLOC(strlen(SMTP_DEFAULT_HELO) + 1);
+	memcpy(smtp_checker->helo_name, SMTP_DEFAULT_HELO, strlen(SMTP_DEFAULT_HELO) + 1);
 
 	/* some other sane values */
-	smtp_chk->timeout = 5 * TIMER_HZ;
-	smtp_chk->db_retry = 1 * TIMER_HZ;
-	smtp_chk->retry = 1;
+	smtp_checker->timeout = 5 * TIMER_HZ;
+	smtp_checker->db_retry = 1 * TIMER_HZ;
+	smtp_checker->retry = 1;
 
 	/*
 	 * Have the checker queue code put our checker into the checkers_queue
 	 * list.
 	 *
 	 * queue_checker(void (*free) (void *), void (*dump) (void *),
-	 *               int (*launch) (struct _thread *),
+	 *               int (*launch) (thread_t *),
 	 *               void *data)
 	 */
 	queue_checker(free_smtp_check, dump_smtp_check, smtp_connect_thread,
-		      smtp_chk);
+		      smtp_checker);
 
 	/* 
 	 * Last, allocate/setup the list that will hold all the per host 
@@ -152,12 +151,12 @@ smtp_check_handler(vector strvec)
 	 * - it must not be reused, because it was probably located in a
 	 *   different "real_server" section and
 	 * - it must not be freed, because it is still referenced
-	 *   by some other smtp_chk->host.
+	 *   by some other smtp_checker->host.
 	 * This must come after queue_checker()!
 	 */
-	smtp_chk->host = alloc_list(smtp_free_host, smtp_dump_host);
+	smtp_checker->host = alloc_list(smtp_free_host, smtp_dump_host);
 	default_host = smtp_alloc_host();
-	list_add(smtp_chk->host, default_host);
+	list_add(smtp_checker->host, default_host);
 }
 
 /* 
@@ -167,79 +166,79 @@ smtp_check_handler(vector strvec)
 void
 smtp_host_handler(vector strvec)
 {
-        smtp_checker *smtp_chk = CHECKER_GET();
+        smtp_checker_t *smtp_checker = CHECKER_GET();
 
 	/*
 	 * If the default host is still allocated, delete it
 	 * before we stick user defined hosts in the list.
 	 */
 	if (default_host) {
-		list_del(smtp_chk->host, default_host);
+		list_del(smtp_checker->host, default_host);
 		FREE(default_host);
 		default_host = NULL;
 	}
 
         /* add an empty host to the list, smtp_checker->host */
-        list_add(smtp_chk->host, smtp_alloc_host());
+        list_add(smtp_checker->host, smtp_alloc_host());
 }
 
 /* "connect_ip" keyword */
 void
 smtp_ip_handler(vector strvec)
 {
-	smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_host *smtp_hst = LIST_TAIL_DATA(smtp_chk->host);
-	inet_ston(VECTOR_SLOT(strvec, 1), &smtp_hst->ip);
+	smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_host_t *smtp_host = LIST_TAIL_DATA(smtp_checker->host);
+	inet_stosockaddr(VECTOR_SLOT(strvec, 1), NULL, &smtp_host->dst);
 }
 
 /* "connect_port" keyword */
 void
 smtp_port_handler(vector strvec)
 {
-	smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_host *smtp_hst = LIST_TAIL_DATA(smtp_chk->host);
-	smtp_hst->port = htons(CHECKER_VALUE_INT(strvec)); 
+	smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_host_t *smtp_host = LIST_TAIL_DATA(smtp_checker->host);
+	checker_set_dst_port(&smtp_host->dst, htons(CHECKER_VALUE_INT(strvec)));
 }
 
 /* "helo_name" keyword */
 void
 smtp_helo_name_handler(vector strvec)
 {
-	smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_chk->helo_name = CHECKER_VALUE_STRING(strvec);
+	smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_checker->helo_name = CHECKER_VALUE_STRING(strvec);
 }
 
 /* "connect_timeout" keyword */
 void
 smtp_timeout_handler(vector strvec)
 {
-	smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_chk->timeout = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
+	smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_checker->timeout = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
 }
 
 /* "retry" keyword */
 void
 smtp_retry_handler(vector strvec)
 {
-        smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_chk->retry = CHECKER_VALUE_INT(strvec);
+        smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_checker->retry = CHECKER_VALUE_INT(strvec);
 }
 
 /* "delay_before_retry" keyword */
 void
 smtp_db_retry_handler(vector strvec)
 {
-        smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_chk->db_retry = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
+        smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_checker->db_retry = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
 }
 
 /* "bindto" keyword */
 void
 smtp_bindto_handler(vector strvec)
 {
-        smtp_checker *smtp_chk = CHECKER_GET();
-	smtp_host *smtp_hst = LIST_TAIL_DATA(smtp_chk->host);
-        inet_ston(VECTOR_SLOT(strvec, 1), &smtp_hst->bindto);
+        smtp_checker_t *smtp_checker = CHECKER_GET();
+	smtp_host_t *smtp_host = LIST_TAIL_DATA(smtp_checker->host);
+	inet_stosockaddr(VECTOR_SLOT(strvec, 1), 0, &smtp_host->bindto);
 }
 
 /* Config callback installer */
@@ -272,23 +271,23 @@ install_smtp_check_keyword(void)
  * service down in case of error.
  */
 int
-smtp_final(thread *thread_obj, int error, const char *format, ...)
+smtp_final(thread_t *thread, int error, const char *format, ...)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
 	char error_buff[512];
 	char smtp_buff[542];
 	va_list varg_list;
 
 	/* Error or no error we should always have to close the socket */
-	close(thread_obj->u.fd);
+	close(thread->u.fd);
 
 	/* If we're here, an attempt HAS been made already for the current host */
-	smtp_chk->attempts++;
+	smtp_checker->attempts++;
 	
 	if (error) {
 		/* Always syslog the error when the real server is up */
-                if (svr_checker_up(chk->id, chk->rs)) {
+                if (svr_checker_up(checker->id, checker->rs)) {
 			if (format != NULL) {
 				memcpy(error_buff, "SMTP_CHECK ", 11);
 				va_start(varg_list, format);
@@ -307,9 +306,9 @@ smtp_final(thread *thread_obj, int error, const char *format, ...)
 		 * scheduling the main thread to check it again after the
 		 * configured backoff delay. Otherwise down the RS.
 		 */
-		if (smtp_chk->attempts < smtp_chk->retry) {
-			thread_add_timer(thread_obj->master, smtp_connect_thread, chk,
-					 smtp_chk->db_retry);
+		if (smtp_checker->attempts < smtp_checker->retry) {
+			thread_add_timer(thread->master, smtp_connect_thread, checker,
+					 smtp_checker->db_retry);
 			return 0;
 		}
 
@@ -319,7 +318,7 @@ smtp_final(thread *thread_obj, int error, const char *format, ...)
 		 * be noted that smtp_alert makes a copy of the string arguments, so
 		 * we don't have to keep them statically allocated.
 		 */
-                if (svr_checker_up(chk->id, chk->rs)) {
+                if (svr_checker_up(checker->id, checker->rs)) {
 			if (format != NULL) {
 				snprintf(smtp_buff, 542, "=> CHECK failed on service : %s <=",
 					 error_buff + 11);
@@ -328,16 +327,16 @@ smtp_final(thread *thread_obj, int error, const char *format, ...)
 			}
 
 			smtp_buff[542 - 1] = '\0';
-			smtp_alert(chk->rs, NULL, NULL, "DOWN", smtp_buff);
-			update_svr_checker_state(DOWN, chk->id, chk->vs, chk->rs);
+			smtp_alert(checker->rs, NULL, NULL, "DOWN", smtp_buff);
+			update_svr_checker_state(DOWN, checker->id, checker->vs, checker->rs);
 		}
 
 		/* Reset everything back to the first host in the list */
-		smtp_chk->attempts = 0;
-		smtp_chk->host_ctr = 0;
+		smtp_checker->attempts = 0;
+		smtp_checker->host_ctr = 0;
 
 		/* Reschedule the main thread using the configured delay loop */;
-		thread_add_timer(thread_obj->master, smtp_connect_thread, chk, chk->vs->delay_loop);
+		thread_add_timer(thread->master, smtp_connect_thread, checker, checker->vs->delay_loop);
 
 		return 0;
 	}	
@@ -348,10 +347,10 @@ smtp_final(thread *thread_obj, int error, const char *format, ...)
 	 * If host_ctr exceeds the number of hosts in the list, http_main_thread will
 	 * take note and bring up the real server as well as inject the delay_loop.
 	 */
-	smtp_chk->attempts = 0;
-	smtp_chk->host_ctr++;
+	smtp_checker->attempts = 0;
+	smtp_checker->host_ctr++;
 
-	thread_add_timer(thread_obj->master, smtp_connect_thread, chk, 1);
+	thread_add_timer(thread->master, smtp_connect_thread, checker, 1);
 	return 0;
 }
 
@@ -359,12 +358,12 @@ smtp_final(thread *thread_obj, int error, const char *format, ...)
  * Zeros out the rx/tx buffer
  */
 void
-smtp_clear_buff(thread *thread_obj)
+smtp_clear_buff(thread_t *thread)
 {
-        checker *chk = THREAD_ARG(thread_obj);
-        smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	memset(smtp_chk->buff, 0, SMTP_BUFF_MAX);
-	smtp_chk->buff_ctr = 0;
+        checker_t *checker = THREAD_ARG(thread);
+        smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	memset(smtp_checker->buff, 0, SMTP_BUFF_MAX);
+	smtp_checker->buff_ctr = 0;
 }
 
 /*
@@ -374,56 +373,60 @@ smtp_clear_buff(thread *thread_obj)
  * SMTP response codes at the beginning anyway.
  */
 int
-smtp_get_line_cb(thread *thread_obj)
+smtp_get_line_cb(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	smtp_host *smtp_hst = smtp_chk->host_ptr;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	smtp_host_t *smtp_host = smtp_checker->host_ptr;
 	int f, r, x;
 
         /* Handle read timeout */
-        if (thread_obj->type == THREAD_READ_TIMEOUT) {
-		smtp_final(thread_obj, 1, "Read timeout from server [%s:%d]",
-			   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+        if (thread->type == THREAD_READ_TIMEOUT) {
+		smtp_final(thread, 1, "Read timeout from server [%s:%d]"
+				    , inet_sockaddrtos(&smtp_host->dst)
+				    , ntohs(inet_sockaddrport(&smtp_host->dst)));
 		return 0;
 	}
 
 	/* wrap the buffer, if full, by clearing it */
-	if (SMTP_BUFF_MAX - smtp_chk->buff_ctr <= 0) {
+	if (SMTP_BUFF_MAX - smtp_checker->buff_ctr <= 0) {
 		log_message(LOG_INFO, "SMTP_CHECK Buffer overflow reading from server [%s:%d]. "
-		       "Increase SMTP_BUFF_MAX in smtp_check.h",
-		       inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
-		smtp_clear_buff(thread_obj);
+				      "Increase SMTP_BUFF_MAX in smtp_check.h"
+				    , inet_sockaddrtos(&smtp_host->dst)
+				    , ntohs(inet_sockaddrport(&smtp_host->dst)));
+		smtp_clear_buff(thread);
 	}
 
 	/* Set descriptor non blocking */
-        f = fcntl(thread_obj->u.fd, F_GETFL, 0);
-        fcntl(thread_obj->u.fd, F_SETFL, f | O_NONBLOCK);
+	f = fcntl(thread->u.fd, F_GETFL, 0);
+	fcntl(thread->u.fd, F_SETFL, f | O_NONBLOCK);
 
-        /* read the data */
-        r = read(thread_obj->u.fd, smtp_chk->buff + smtp_chk->buff_ctr,
-                 SMTP_BUFF_MAX - smtp_chk->buff_ctr);
+	/* read the data */
+	r = read(thread->u.fd, smtp_checker->buff + smtp_checker->buff_ctr,
+		 SMTP_BUFF_MAX - smtp_checker->buff_ctr);
 
 	if (r == -1 && (errno == EAGAIN || errno == EINTR)) {
-		thread_add_read(thread_obj->master, smtp_get_line_cb, chk,
-				thread_obj->u.fd, smtp_chk->timeout);
-        	fcntl(thread_obj->u.fd, F_SETFL, f);
+		thread_add_read(thread->master, smtp_get_line_cb, checker,
+				thread->u.fd, smtp_checker->timeout);
+        	fcntl(thread->u.fd, F_SETFL, f);
 		return 0;
 	} else if (r > 0)
-		smtp_chk->buff_ctr += r;
+		smtp_checker->buff_ctr += r;
 
         /* restore descriptor flags */
-        fcntl(thread_obj->u.fd, F_SETFL, f);
+        fcntl(thread->u.fd, F_SETFL, f);
 
 	/* check if we have a newline, if so, callback */
 	for (x = 0; x < SMTP_BUFF_MAX; x++) {
-		if (smtp_chk->buff[x] == '\n') {
-			smtp_chk->buff[SMTP_BUFF_MAX - 1] = '\0';
+		if (smtp_checker->buff[x] == '\n') {
+			smtp_checker->buff[SMTP_BUFF_MAX - 1] = '\0';
 			
-			DBG("SMTP_CHECK [%s:%d] < %s", inet_ntop2(smtp_hst->ip),
-			    ntohs(smtp_hst->port), smtp_chk->buff);
+			DBG("SMTP_CHECK [%s:%d] < %s"
+			    , inet_sockaddrtos(&smtp_host->dst)
+			    , ntohs(inet_sockaddrport(&smtp_host->dst))
+			    , smtp_checker->buff);
 
-			(smtp_chk->buff_cb)(thread_obj);
+			(smtp_checker->buff_cb)(thread);
 
 			return 0;
 		}
@@ -434,8 +437,9 @@ smtp_get_line_cb(thread *thread_obj)
 	 * some sort of error, notify smtp_final()
 	 */
 	if (r <= 0) {
-		smtp_final(thread_obj, 1, "Read failure from server [%s:%d]",
-			   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+		smtp_final(thread, 1, "Read failure from server [%s:%d]"
+				     , inet_sockaddrtos(&smtp_host->dst)
+				     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 		return 0;
 	}
 
@@ -444,8 +448,8 @@ smtp_get_line_cb(thread *thread_obj)
 	 * to pull a newline. Schedule ourselves for
 	 * another round.
 	 */
-	thread_add_read(thread_obj->master, smtp_get_line_cb, chk,
-			thread_obj->u.fd, smtp_chk->timeout);
+	thread_add_read(thread->master, smtp_get_line_cb, checker,
+			thread->u.fd, smtp_checker->timeout);
 	return 0;
 }
 
@@ -459,20 +463,20 @@ smtp_get_line_cb(thread *thread_obj)
  * sceduler can only accept a single *thread argument.
  */
 void
-smtp_get_line(thread *thread_obj, int (*callback) (struct _thread *))
+smtp_get_line(thread_t *thread, int (*callback) (thread_t *))
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
 
 	/* clear the buffer */
-	smtp_clear_buff(thread_obj);
+	smtp_clear_buff(thread);
 
 	/* set the callback */
-	smtp_chk->buff_cb = callback;
+	smtp_checker->buff_cb = callback;
 
 	/* schedule the I/O with our helper function  */
-	thread_add_read(thread_obj->master, smtp_get_line_cb, chk,
-		thread_obj->u.fd, smtp_chk->timeout);
+	thread_add_read(thread->master, smtp_get_line_cb, checker,
+		thread->u.fd, smtp_checker->timeout);
 	return;
 }
 
@@ -483,53 +487,57 @@ smtp_get_line(thread *thread_obj, int (*callback) (struct _thread *))
  * we'll return to the scheduler and try again later. 
  */
 int
-smtp_put_line_cb(thread *thread_obj)
+smtp_put_line_cb(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	smtp_host *smtp_hst = smtp_chk->host_ptr;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	smtp_host_t *smtp_host = smtp_checker->host_ptr;
 	int f, w;
 
 
         /* Handle read timeout */
-        if (thread_obj->type == THREAD_WRITE_TIMEOUT) {
-		smtp_final(thread_obj, 1, "Write timeout to server [%s:%d]",
-			   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+        if (thread->type == THREAD_WRITE_TIMEOUT) {
+		smtp_final(thread, 1, "Write timeout to server [%s:%d]"
+				     , inet_sockaddrtos(&smtp_host->dst)
+				     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 		return 0;
 	}
 
 	/* Set descriptor non blocking */
-        f = fcntl(thread_obj->u.fd, F_GETFL, 0);
-        fcntl(thread_obj->u.fd, F_SETFL, f | O_NONBLOCK);
+        f = fcntl(thread->u.fd, F_GETFL, 0);
+        fcntl(thread->u.fd, F_SETFL, f | O_NONBLOCK);
 
         /* write the data */
-        w = write(thread_obj->u.fd, smtp_chk->buff, smtp_chk->buff_ctr);
+        w = write(thread->u.fd, smtp_checker->buff, smtp_checker->buff_ctr);
 
 	if (w == -1 && (errno == EAGAIN || errno == EINTR)) {
-		thread_add_write(thread_obj->master, smtp_put_line_cb, chk,
-				 thread_obj->u.fd, smtp_chk->timeout);
-        	fcntl(thread_obj->u.fd, F_SETFL, f);
+		thread_add_write(thread->master, smtp_put_line_cb, checker,
+				 thread->u.fd, smtp_checker->timeout);
+        	fcntl(thread->u.fd, F_SETFL, f);
 		return 0;
 	}
 
         /* restore descriptor flags */
-        fcntl(thread_obj->u.fd, F_SETFL, f);
+        fcntl(thread->u.fd, F_SETFL, f);
 
-	DBG("SMTP_CHECK [%s:%d] > %s", inet_ntop2(smtp_hst->ip),
-	    ntohs(smtp_hst->port), smtp_chk->buff);
+	DBG("SMTP_CHECK [%s:%d] > %s"
+	    , inet_sockaddrtos(&smtp_host->dst)
+	    , ntohs(inet_sockaddrport(&smtp_host->dst))
+	    , smtp_checker->buff);
 
 	/*
 	 * If the connection was closed or there was
 	 * some sort of error, notify smtp_final()
 	 */
 	if (w <= 0) {
-		smtp_final(thread_obj, 1, "Write failure to server [%s:%d]",
-			   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+		smtp_final(thread, 1, "Write failure to server [%s:%d]"
+				     , inet_sockaddrtos(&smtp_host->dst)
+				     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 		return 0;
 	}
 
 	/* Execute the callback */
-	(smtp_chk->buff_cb)(thread_obj);
+	(smtp_checker->buff_cb)(thread);
 	return 0;
 }
 
@@ -538,20 +546,20 @@ smtp_put_line_cb(thread *thread_obj)
  * line of data instead of receiving one.
  */
 void
-smtp_put_line(thread *thread_obj, int (*callback) (struct _thread *))
+smtp_put_line(thread_t *thread, int (*callback) (thread_t *))
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
 
-	smtp_chk->buff[SMTP_BUFF_MAX - 1] = '\0';
-	smtp_chk->buff_ctr = strlen(smtp_chk->buff);
+	smtp_checker->buff[SMTP_BUFF_MAX - 1] = '\0';
+	smtp_checker->buff_ctr = strlen(smtp_checker->buff);
 
 	/* set the callback */
-	smtp_chk->buff_cb = callback;
+	smtp_checker->buff_cb = callback;
 
 	/* schedule the I/O with our helper function  */
-	thread_add_write(thread_obj->master, smtp_put_line_cb, chk,
-			 thread_obj->u.fd, smtp_chk->timeout);
+	thread_add_write(thread->master, smtp_put_line_cb, checker,
+			 thread->u.fd, smtp_checker->timeout);
 	return;
 }
 
@@ -561,11 +569,11 @@ smtp_put_line(thread *thread_obj, int (*callback) (struct _thread *))
  * return -1.
  */
 int
-smtp_get_status(thread *thread_obj)
+smtp_get_status(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	char *buff = smtp_chk->buff;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	char *buff = smtp_checker->buff;
 
 	/* First make sure they're all digits */	
 	if (isdigit(buff[0]) && isdigit(buff[1]) &&
@@ -582,17 +590,17 @@ smtp_get_status(thread *thread_obj)
  * We have a connected socket and are ready to begin 
  * the conversation. This function schedules itself to 
  * be called via callbacks and tracking state in 
- * smtp_chk->state. Upon first calling, smtp_chk->state 
+ * smtp_checker->state. Upon first calling, smtp_checker->state 
  * should be set to SMTP_START.
  */
 int
-smtp_engine_thread(thread *thread_obj)
+smtp_engine_thread(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	smtp_host *smtp_hst = smtp_chk->host_ptr;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	smtp_host_t *smtp_host = smtp_checker->host_ptr;
 
-	switch (smtp_chk->state) {
+	switch (smtp_checker->state) {
 
 		/* First step, schedule to receive the greeting banner */
 		case SMTP_START:
@@ -601,17 +609,18 @@ smtp_engine_thread(thread *thread_obj)
 			 * have data to analyze. Otherwise, smtp_get_line
 			 * will defer directly to smtp_final.
 			 */
-			smtp_chk->state = SMTP_HAVE_BANNER;
-			smtp_get_line(thread_obj, smtp_engine_thread);
+			smtp_checker->state = SMTP_HAVE_BANNER;
+			smtp_get_line(thread, smtp_engine_thread);
 			return 0;
 			break;
 
 		/* Second step, analyze banner, send HELO */
 		case SMTP_HAVE_BANNER:
 			/* Check for "220 some.mailserver.com" in the greeting */
-			if (smtp_get_status(thread_obj) != 220) {
-				smtp_final(thread_obj, 1, "Bad greeting banner from server [%s:%d]",
-					inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+			if (smtp_get_status(thread) != 220) {
+				smtp_final(thread, 1, "Bad greeting banner from server [%s:%d]"
+						     , inet_sockaddrtos(&smtp_host->dst)
+						     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 
 				return 0;
 			}
@@ -620,52 +629,53 @@ smtp_engine_thread(thread *thread_obj)
 			 * Schedule to send the HELO, smtp_put_line will
 			 * defer directly to smtp_final on error.
 			 */
-			smtp_chk->state = SMTP_SENT_HELO;
-			snprintf(smtp_chk->buff, SMTP_BUFF_MAX, "HELO %s\r\n",
-				 smtp_chk->helo_name);
-			smtp_put_line(thread_obj, smtp_engine_thread);
+			smtp_checker->state = SMTP_SENT_HELO;
+			snprintf(smtp_checker->buff, SMTP_BUFF_MAX, "HELO %s\r\n",
+				 smtp_checker->helo_name);
+			smtp_put_line(thread, smtp_engine_thread);
 			return 0;
 			break;
 
 		/* Third step, schedule to read the HELO response */
 		case SMTP_SENT_HELO:
-			smtp_chk->state = SMTP_RECV_HELO;
-			smtp_get_line(thread_obj, smtp_engine_thread);
+			smtp_checker->state = SMTP_RECV_HELO;
+			smtp_get_line(thread, smtp_engine_thread);
 			return 0;
 			break;
 
 		/* Fourth step, analyze HELO return, send QUIT */
 		case SMTP_RECV_HELO:
 			/* Check for "250 Please to meet you..." */
-			if (smtp_get_status(thread_obj) != 250) {
-				smtp_final(thread_obj, 1, "Bad HELO response from server [%s:%d]",
-					inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+			if (smtp_get_status(thread) != 250) {
+				smtp_final(thread, 1, "Bad HELO response from server [%s:%d]"
+						     , inet_sockaddrtos(&smtp_host->dst)
+						     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 
 				return 0;
 			}
 
-			smtp_chk->state = SMTP_SENT_QUIT;
-			snprintf(smtp_chk->buff, SMTP_BUFF_MAX, "QUIT\r\n");
-			smtp_put_line(thread_obj, smtp_engine_thread);
+			smtp_checker->state = SMTP_SENT_QUIT;
+			snprintf(smtp_checker->buff, SMTP_BUFF_MAX, "QUIT\r\n");
+			smtp_put_line(thread, smtp_engine_thread);
 			return 0;
 			break;
 
 		/* Fifth step, schedule to receive QUIT confirmation */
 		case SMTP_SENT_QUIT:
-			smtp_chk->state = SMTP_RECV_QUIT;
-			smtp_get_line(thread_obj, smtp_engine_thread);
+			smtp_checker->state = SMTP_RECV_QUIT;
+			smtp_get_line(thread, smtp_engine_thread);
 			return 0;
 			break;
 
 		/* Sixth step, wrap up success to smtp_final */
 		case SMTP_RECV_QUIT:
-			smtp_final(thread_obj, 0, NULL);
+			smtp_final(thread, 0, NULL);
 			return 0;
 			break;
 	}
 
 	/* We shouldn't be here */
-	smtp_final(thread_obj, 1, "Unknown smtp engine state encountered");
+	smtp_final(thread, 1, "Unknown smtp engine state encountered");
 	return 0;
 }
 		
@@ -674,42 +684,45 @@ smtp_engine_thread(thread *thread_obj)
  * to the host we're checking was successful or not.
  */
 int
-smtp_check_thread(thread *thread_obj)
+smtp_check_thread(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	smtp_host *smtp_hst = smtp_chk->host_ptr;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	smtp_host_t *smtp_host = smtp_checker->host_ptr;
 	int status;
 
-	status = tcp_socket_state(thread_obj->u.fd, thread_obj, smtp_hst->ip,
-				  smtp_hst->port, smtp_check_thread);
+	status = tcp_socket_state(thread->u.fd, thread, smtp_check_thread);
 	switch (status) {
 		case connect_error:
-			smtp_final(thread_obj, 1, "Error connecting to server [%s:%d]",
-				   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+			smtp_final(thread, 1, "Error connecting to server [%s:%d]"
+					     , inet_sockaddrtos(&smtp_host->dst)
+					     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 			return 0;
 			break;
 
 		case connect_timeout:
-			smtp_final(thread_obj, 1, "Connection timeout to server [%s:%d]",
-				   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+			smtp_final(thread, 1, "Connection timeout to server [%s:%d]"
+					     , inet_sockaddrtos(&smtp_host->dst)
+					     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 			return 0;
 			break;
 
 		case connect_success:
-			DBG("SMTP_CHECK Remote SMTP server [%s:%d] connected",
-			    inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+			DBG("SMTP_CHECK Remote SMTP server [%s:%d] connected"
+			    , inet_sockaddrtos(&smtp_host->dst)
+			    , ntohs(inet_sockaddrport(&smtp_host->dst)));
 
 			/* Enter the engine at SMTP_START */
-			smtp_chk->state = SMTP_START;
-			smtp_engine_thread(thread_obj);
+			smtp_checker->state = SMTP_START;
+			smtp_engine_thread(thread);
 			return 0;
 			break;
 	}
 
 	/* we shouldn't be here */		
-	smtp_final(thread_obj, 1, "Unknown connection error to server [%s:%d]",
-		   inet_ntop2(smtp_hst->ip), ntohs(smtp_hst->port));
+	smtp_final(thread, 1, "Unknown connection error to server [%s:%d]"
+			     , inet_sockaddrtos(&smtp_host->dst)
+			     , ntohs(inet_sockaddrport(&smtp_host->dst)));
 	return 0;
 }
 
@@ -724,11 +737,11 @@ smtp_check_thread(thread *thread_obj)
  * but eventually has to happen.
  */
 int
-smtp_connect_thread(thread *thread_obj)
+smtp_connect_thread(thread_t *thread)
 {
-	checker *chk = THREAD_ARG(thread_obj);
-	smtp_checker *smtp_chk = CHECKER_ARG(chk);
-	smtp_host *smtp_hst;
+	checker_t *checker = THREAD_ARG(thread);
+	smtp_checker_t *smtp_checker = CHECKER_ARG(checker);
+	smtp_host_t *smtp_host;
 	enum connect_result status;
 	int sd;
 
@@ -752,9 +765,9 @@ smtp_connect_thread(thread *thread_obj)
 	 * thread->arg(checker)->data(smtp_checker)->host(smtp_host)
 	 * 
 	 * To make life simple, we'll break the structures out so
-	 * that "chk" always points to the current checker structure,
-	 * "smtp_chk" points to the current smtp_checker structure, 
-	 * and "smtp_hst" points to the current smtp_host structure.
+	 * that "checker" always points to the current checker structure,
+	 * "smtp_checker" points to the current smtp_checker structure, 
+	 * and "smtp_host" points to the current smtp_host structure.
 	 */
 
 	/*
@@ -762,9 +775,9 @@ smtp_connect_thread(thread *thread_obj)
 	 * But we still have to register ourselves again so
 	 * we don't fall of the face of the earth.
 	 */
-	if (!CHECKER_ENABLED(chk)) {
-		thread_add_timer(thread_obj->master, smtp_connect_thread, chk,
-				 chk->vs->delay_loop);
+	if (!CHECKER_ENABLED(checker)) {
+		thread_add_timer(thread->master, smtp_connect_thread, checker,
+				 checker->vs->delay_loop);
 		return 0;
 	}
 
@@ -775,37 +788,43 @@ smtp_connect_thread(thread *thread_obj)
 	 * and insert the delay loop. When we get scheduled again the host list
 	 * will be reset and we will continue on checking them one by one.
 	 */
-	if ((smtp_chk->host_ptr = list_element(smtp_chk->host, smtp_chk->host_ctr)) == NULL) {
-		if (!svr_checker_up(chk->id, chk->rs)) {
-			log_message(LOG_INFO, "Remote SMTP server [%s:%d] succeed on service.",
-			       inet_ntop2(CHECKER_RIP(chk)), ntohs(CHECKER_RPORT(chk)));
+	if ((smtp_checker->host_ptr = list_element(smtp_checker->host, smtp_checker->host_ctr)) == NULL) {
+		if (!svr_checker_up(checker->id, checker->rs)) {
+			log_message(LOG_INFO, "Remote SMTP server [%s:%d] succeed on service."
+					    , inet_sockaddrtos(&checker->rs->addr)
+					    , ntohs(inet_sockaddrport(&checker->rs->addr)));
 
-			smtp_alert(chk->rs, NULL, NULL, "UP",
+			smtp_alert(checker->rs, NULL, NULL, "UP",
 				   "=> CHECK succeed on service <=");
-			update_svr_checker_state(UP, chk->id, chk->vs, chk->rs);
+			update_svr_checker_state(UP, checker->id, checker->vs, checker->rs);
 		}
 
-		smtp_chk->attempts = 0;
-		smtp_chk->host_ctr = 0;
-		smtp_chk->host_ptr = list_element(smtp_chk->host, 0);
+		smtp_checker->attempts = 0;
+		smtp_checker->host_ctr = 0;
+		smtp_checker->host_ptr = list_element(smtp_checker->host, 0);
 
-		thread_add_timer(thread_obj->master, smtp_connect_thread, chk, chk->vs->delay_loop);
+		thread_add_timer(thread->master, smtp_connect_thread, checker, checker->vs->delay_loop);
 		return 0;
 	}
 
-	smtp_hst = smtp_chk->host_ptr;
+	smtp_host = smtp_checker->host_ptr;
 
 	/* Create the socket, failling here should be an oddity */
-	if ((sd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == -1) {
+	if ((sd = socket(smtp_host->dst.ss_family, SOCK_STREAM, IPPROTO_TCP)) == -1) {
 		DBG("SMTP_CHECK connection failed to create socket.");
-		thread_add_timer(thread_obj->master, smtp_connect_thread, chk,
-				 chk->vs->delay_loop);
+		thread_add_timer(thread->master, smtp_connect_thread, checker,
+				 checker->vs->delay_loop);
 		return 0;
 	}
 
-	status = tcp_bind_connect(sd, smtp_hst->ip, smtp_hst->port, smtp_hst->bindto);
+	status = tcp_bind_connect(sd, &smtp_host->dst, &smtp_host->bindto);
+	if (status == connect_error) {
+		thread_add_timer(thread->master, smtp_connect_thread, checker,
+				 checker->vs->delay_loop);
+		return 0;
+	}
 
 	/* handle tcp connection status & register callback the next setp in the process */
-	tcp_connection_state(sd, status, thread_obj, smtp_check_thread, smtp_chk->timeout);
+	tcp_connection_state(sd, status, thread, smtp_check_thread, smtp_checker->timeout);
 	return 0;
 }
