@@ -20,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <openssl/err.h>
@@ -188,30 +188,30 @@ ssl_printerr(int err)
 }
 
 int
-ssl_connect(thread * thread_obj, int new_req)
+ssl_connect(thread_t * thread, int new_req)
 {
-	checker *checker_obj = THREAD_ARG(thread_obj);
-	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
-	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg_obj);
+	checker_t *checker = THREAD_ARG(thread);
+	http_checker_t *http_get_check = CHECKER_ARG(checker);
+	http_arg_t *http_arg = HTTP_ARG(http_get_check);
+	request_t *req = HTTP_REQ(http_arg);
 	int ret = 0;
 	int val = 0;
 
 	/* First round, create SSL context */
 	if (new_req) {
 		req->ssl = SSL_new(check_data->ssl->ctx);
-		req->bio = BIO_new_socket(thread_obj->u.fd, BIO_NOCLOSE);
+		req->bio = BIO_new_socket(thread->u.fd, BIO_NOCLOSE);
 		SSL_set_bio(req->ssl, req->bio, req->bio);
 	}
 
 	/* Set descriptor non blocking */
-	val = fcntl(thread_obj->u.fd, F_GETFL, 0);
-	fcntl(thread_obj->u.fd, F_SETFL, val | O_NONBLOCK);
+	val = fcntl(thread->u.fd, F_GETFL, 0);
+	fcntl(thread->u.fd, F_SETFL, val | O_NONBLOCK);
 
 	ret = SSL_connect(req->ssl);
 
 	/* restore descriptor flags */
-	fcntl(thread_obj->u.fd, F_SETFL, val);
+	fcntl(thread->u.fd, F_SETFL, val);
 
 	return ret;
 }
@@ -238,38 +238,38 @@ ssl_send_request(SSL * ssl, char *str_request, int request_len)
 
 /* Asynchronous SSL stream reader */
 int
-ssl_read_thread(thread * thread_obj)
+ssl_read_thread(thread_t * thread)
 {
-	checker *checker_obj = THREAD_ARG(thread_obj);
-	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
-	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg_obj);
+	checker_t *checker = THREAD_ARG(thread);
+	http_checker_t *http_get_check = CHECKER_ARG(checker);
+	http_arg_t *http_arg = HTTP_ARG(http_get_check);
+	request_t *req = HTTP_REQ(http_arg);
 	unsigned char digest[16];
 	int r = 0;
 	int val;
 
 	/* Handle read timeout */
-	if (thread_obj->type == THREAD_READ_TIMEOUT && !req->extracted)
-		return timeout_epilog(thread_obj, "=> SSL CHECK failed on service"
+	if (thread->type == THREAD_READ_TIMEOUT && !req->extracted)
+		return timeout_epilog(thread, "=> SSL CHECK failed on service"
 				      " : recevice data <=\n\n", "SSL read");
 
 	/* Set descriptor non blocking */
-	val = fcntl(thread_obj->u.fd, F_GETFL, 0);
-	fcntl(thread_obj->u.fd, F_SETFL, val | O_NONBLOCK);
+	val = fcntl(thread->u.fd, F_GETFL, 0);
+	fcntl(thread->u.fd, F_SETFL, val | O_NONBLOCK);
 
 	/* read the SSL stream */
 	r = SSL_read(req->ssl, req->buffer + req->len,
 		     MAX_BUFFER_LENGTH - req->len);
 
 	/* restore descriptor flags */
-	fcntl(thread_obj->u.fd, F_SETFL, val);
+	fcntl(thread->u.fd, F_SETFL, val);
 
 	req->error = SSL_get_error(req->ssl, r);
 
 	if (req->error == SSL_ERROR_WANT_READ) {
 		 /* async read unfinished */ 
-		thread_add_read(thread_obj->master, ssl_read_thread, checker_obj,
-				thread_obj->u.fd, http_get_check->connection_to);
+		thread_add_read(thread->master, ssl_read_thread, checker,
+				thread->u.fd, http_get_check->connection_to);
 	} else if (r > 0 && req->error == 0) {
 		/* Handle response stream */
 		http_process_response(req, r);
@@ -278,33 +278,32 @@ ssl_read_thread(thread * thread_obj)
 		 * Register next ssl stream reader.
 		 * Register itself to not perturbe global I/O multiplexer.
 		 */
-		thread_add_read(thread_obj->master, ssl_read_thread, checker_obj,
-				thread_obj->u.fd, http_get_check->connection_to);
+		thread_add_read(thread->master, ssl_read_thread, checker,
+				thread->u.fd, http_get_check->connection_to);
 	} else if (req->error) {
 
 		/* All the SSL streal has been parsed */
 		MD5_Final(digest, &req->context);
 		SSL_set_quiet_shutdown(req->ssl, 1);
 
-		r = (req->error ==
-		     SSL_ERROR_ZERO_RETURN) ? SSL_shutdown(req->ssl) : 0;
+		r = (req->error == SSL_ERROR_ZERO_RETURN) ? SSL_shutdown(req->ssl) : 0;
 
 		if (r && !req->extracted) {
 			/* check if server is currently alive */
-			if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
-				smtp_alert(checker_obj->rs, NULL, NULL,
+			if (svr_checker_up(checker->id, checker->rs)) {
+				smtp_alert(checker->rs, NULL, NULL,
 					   "DOWN",
 					   "=> SSL CHECK failed on service"
 					   " : cannot receive data <=\n\n");
-				update_svr_checker_state(DOWN, checker_obj->id
-							     , checker_obj->vs
-							     , checker_obj->rs);
+				update_svr_checker_state(DOWN, checker->id
+							     , checker->vs
+							     , checker->rs);
 			}
-			return epilog(thread_obj, 1, 0, 0);
+			return epilog(thread, 1, 0, 0);
 		}
 
 		/* Handle response stream */
-		http_handle_response(thread_obj, digest, (!req->extracted) ? 1 : 0);
+		http_handle_response(thread, digest, (!req->extracted) ? 1 : 0);
 
 	}
 
