@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "check_tcp.h"
@@ -30,13 +30,13 @@
 #include "utils.h"
 #include "parser.h"
 
-int tcp_connect_thread(thread *);
+int tcp_connect_thread(thread_t *);
 
 /* Configuration stream handling */
 void
 free_tcp_check(void *data)
 {
-	tcp_checker *tcp_chk = CHECKER_DATA(data);
+	tcp_checker_t *tcp_chk = CHECKER_DATA(data);
 
 	FREE(tcp_chk);
 	FREE(data);
@@ -45,45 +45,44 @@ free_tcp_check(void *data)
 void
 dump_tcp_check(void *data)
 {
-	tcp_checker *tcp_chk = CHECKER_DATA(data);
+	tcp_checker_t *tcp_chk = CHECKER_DATA(data);
 
 	log_message(LOG_INFO, "   Keepalive method = TCP_CHECK");
-	if (tcp_chk->connection_port)
-		log_message(LOG_INFO, "   Connection port = %d",
-		       ntohs(tcp_chk->connection_port));
-	if (tcp_chk->bindto)
-		log_message(LOG_INFO, "   Bind to = %s", inet_ntop2(tcp_chk->bindto));
+	log_message(LOG_INFO, "   Connection port = %d", ntohs(inet_sockaddrport(&tcp_chk->dst)));
+	if (tcp_chk->bindto.ss_family)
+		log_message(LOG_INFO, "   Bind to = %s", inet_sockaddrtos(&tcp_chk->bindto));
 	log_message(LOG_INFO, "   Connection timeout = %d", tcp_chk->connection_to/TIMER_HZ);
 }
 
 void
 tcp_check_handler(vector strvec)
 {
-	tcp_checker *tcp_chk = (tcp_checker *) MALLOC(sizeof (tcp_checker));
+	tcp_checker_t *tcp_chk = (tcp_checker_t *) MALLOC(sizeof (tcp_checker_t));
 
 	/* queue new checker */
-	queue_checker(free_tcp_check, dump_tcp_check, tcp_connect_thread,
-		      tcp_chk);
+	checker_set_dst(&tcp_chk->dst);
+	queue_checker(free_tcp_check, dump_tcp_check, tcp_connect_thread, tcp_chk);
 }
 
 void
 connect_port_handler(vector strvec)
 {
-	tcp_checker *tcp_chk = CHECKER_GET();
-	tcp_chk->connection_port = htons(CHECKER_VALUE_INT(strvec));
+	tcp_checker_t *tcp_chk = CHECKER_GET();
+
+	checker_set_dst_port(&tcp_chk->dst, htons(CHECKER_VALUE_INT(strvec)));
 }
 
 void
 bind_handler(vector strvec)
 {
-	tcp_checker *tcp_chk = CHECKER_GET();
-	inet_ston(VECTOR_SLOT(strvec, 1), &tcp_chk->bindto);
+	tcp_checker_t *tcp_chk = CHECKER_GET();
+	inet_stosockaddr(VECTOR_SLOT(strvec, 1), 0, &tcp_chk->bindto);
 }
 
 void
 connect_timeout_handler(vector strvec)
 {
-	tcp_checker *tcp_chk = CHECKER_GET();
+	tcp_checker_t *tcp_chk = CHECKER_GET();
 	tcp_chk->connection_to = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
 }
 
@@ -99,95 +98,90 @@ install_tcp_check_keyword(void)
 }
 
 int
-tcp_check_thread(thread * thread_obj)
+tcp_check_thread(thread_t * thread)
 {
-	checker *checker_obj;
-	tcp_checker *tcp_check;
-	uint16_t addr_port;
+	checker_t *checker;
+	tcp_checker_t *tcp_check;
 	int status;
 
-	checker_obj = THREAD_ARG(thread_obj);
-	tcp_check = CHECKER_ARG(checker_obj);
+	checker = THREAD_ARG(thread);
+	tcp_check = CHECKER_ARG(checker);
 
-	addr_port = CHECKER_RPORT(checker_obj);
-	if (tcp_check->connection_port)
-		addr_port = tcp_check->connection_port;
-	status = tcp_socket_state(thread_obj->u.fd, thread_obj, CHECKER_RIP(checker_obj)
-				  , addr_port, tcp_check_thread);
+	status = tcp_socket_state(thread->u.fd, thread, tcp_check_thread);
 
 	/* If status = connect_success, TCP connection to remote host is established.
 	 * Otherwise we have a real connection error or connection timeout.
 	 */
 	if (status == connect_success) {
-		close(thread_obj->u.fd);
+		close(thread->u.fd);
 
-		if (!svr_checker_up(checker_obj->id, checker_obj->rs)) {
-			log_message(LOG_INFO, "TCP connection to [%s:%d] success.",
-			       inet_ntop2(CHECKER_RIP(checker_obj))
-			       , ntohs(addr_port));
-			smtp_alert(checker_obj->rs, NULL, NULL,
+		if (!svr_checker_up(checker->id, checker->rs)) {
+			log_message(LOG_INFO, "TCP connection to [%s]:%d success."
+					    , inet_sockaddrtos(&tcp_check->dst)
+					    , ntohs(inet_sockaddrport(&tcp_check->dst)));
+			smtp_alert(checker->rs, NULL, NULL,
 				   "UP",
 				   "=> TCP CHECK succeed on service <=");
-			update_svr_checker_state(UP, checker_obj->id
-						   , checker_obj->vs
-						   , checker_obj->rs);
+			update_svr_checker_state(UP, checker->id
+						   , checker->vs
+						   , checker->rs);
 		}
 
 	} else {
 
-		if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
-			log_message(LOG_INFO, "TCP connection to [%s:%d] failed !!!",
-			       inet_ntop2(CHECKER_RIP(checker_obj))
-			       , ntohs(addr_port));
-			smtp_alert(checker_obj->rs, NULL, NULL,
+		if (svr_checker_up(checker->id, checker->rs)) {
+			log_message(LOG_INFO, "TCP connection to [%s]:%d failed !!!"
+					    , inet_sockaddrtos(&tcp_check->dst)
+					    , ntohs(inet_sockaddrport(&tcp_check->dst)));
+			smtp_alert(checker->rs, NULL, NULL,
 				   "DOWN",
 				   "=> TCP CHECK failed on service <=");
-			update_svr_checker_state(DOWN, checker_obj->id
-						     , checker_obj->vs
-						     , checker_obj->rs);
+			update_svr_checker_state(DOWN, checker->id
+						     , checker->vs
+						     , checker->rs);
 		}
 
 	}
 
 	/* Register next timer checker */
 	if (status != connect_in_progress)
-		thread_add_timer(thread_obj->master, tcp_connect_thread, checker_obj,
-				 checker_obj->vs->delay_loop);
+		thread_add_timer(thread->master, tcp_connect_thread, checker,
+				 checker->vs->delay_loop);
 	return 0;
 }
 
 int
-tcp_connect_thread(thread * thread_obj)
+tcp_connect_thread(thread_t * thread)
 {
-	checker *checker_obj = THREAD_ARG(thread_obj);
-	tcp_checker *tcp_check = CHECKER_ARG(checker_obj);
+	checker_t *checker = THREAD_ARG(thread);
+	tcp_checker_t *tcp_check = CHECKER_ARG(checker);
 	int fd;
-	uint16_t addr_port;
 	int status;
 
 	/*
 	 * Register a new checker thread & return
 	 * if checker is disabled
 	 */
-	if (!CHECKER_ENABLED(checker_obj)) {
-		thread_add_timer(thread_obj->master, tcp_connect_thread, checker_obj,
-				 checker_obj->vs->delay_loop);
+	if (!CHECKER_ENABLED(checker)) {
+		thread_add_timer(thread->master, tcp_connect_thread, checker,
+				 checker->vs->delay_loop);
 		return 0;
 	}
 
-	if ((fd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == -1) {
+	if ((fd = socket(tcp_check->dst.ss_family, SOCK_STREAM, IPPROTO_TCP)) == -1) {
 		DBG("TCP connect fail to create socket.");
 		return 0;
 	}
 
-	addr_port = CHECKER_RPORT(checker_obj);
-	if (tcp_check->connection_port)
-		addr_port = tcp_check->connection_port;
-	status = tcp_bind_connect(fd, CHECKER_RIP(checker_obj), addr_port
-				  , tcp_check->bindto);
+	status = tcp_bind_connect(fd, &tcp_check->dst, &tcp_check->bindto);
+	if (status == connect_error) {
+		thread_add_timer(thread->master, tcp_connect_thread, checker,
+				 checker->vs->delay_loop);
+		return 0;
+	}
 
 	/* handle tcp connection status & register check worker thread */
-	tcp_connection_state(fd, status, thread_obj, tcp_check_thread,
+	tcp_connection_state(fd, status, thread, tcp_check_thread,
 			     tcp_check->connection_to);
 	return 0;
 }
