@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "layer4.h"
@@ -26,42 +26,32 @@
 #include "utils.h"
 
 enum connect_result
-tcp_bind_connect(int fd, uint32_t addr_ip, uint16_t addr_port, uint32_t bind_ip)
+tcp_bind_connect(int fd, struct sockaddr_storage *addr, struct sockaddr_storage *bind_addr)
 {
 	struct linger li = { 0 };
-	int long_inet;
-	struct sockaddr_in sa_in;
+	socklen_t addrlen;
 	int ret;
 	int val;
 
 	/* free the tcp port after closing the socket descriptor */
 	li.l_onoff = 1;
 	li.l_linger = 0;
-	setsockopt(fd, SOL_SOCKET, SO_LINGER, (char *) &li,
-		   sizeof (struct linger));
+	setsockopt(fd, SOL_SOCKET, SO_LINGER, (char *) &li, sizeof (struct linger));
 
 	/* Make socket non-block. */
 	val = fcntl(fd, F_GETFL, 0);
 	fcntl(fd, F_SETFL, val | O_NONBLOCK);
 
 	/* Bind socket */
-	long_inet = sizeof (struct sockaddr_in);
-	memset(&sa_in, 0, long_inet);
-
-	if (bind_ip) {
-		sa_in.sin_family = AF_INET;
-		sa_in.sin_addr.s_addr = bind_ip;
-		if (bind(fd, (struct sockaddr *) &sa_in, sizeof (sa_in)) != 0)
+	if (bind_addr) {
+		addrlen = sizeof(*bind_addr);
+		if (bind(fd, (struct sockaddr *) bind_addr, addrlen) != 0)
 			return connect_error;
 	}
 
 	/* Set remote IP and connect */
-	memset(&sa_in, 0, long_inet);
-	sa_in.sin_family = AF_INET;
-	sa_in.sin_port = addr_port;
-	sa_in.sin_addr.s_addr = addr_ip;
-
-	ret = connect(fd, (struct sockaddr *) &sa_in, long_inet);
+	addrlen = sizeof(*addr);
+	ret = connect(fd, (struct sockaddr *) addr, addrlen);
 
 	/* Immediate success */
 	if (ret == 0) {
@@ -81,39 +71,33 @@ tcp_bind_connect(int fd, uint32_t addr_ip, uint16_t addr_port, uint32_t bind_ip)
 }
 
 enum connect_result
-tcp_connect(int fd, uint32_t addr_ip, uint16_t addr_port)
+tcp_connect(int fd, struct sockaddr_storage *addr)
 {
-	return tcp_bind_connect(fd, addr_ip, addr_port, 0);
+	return tcp_bind_connect(fd, addr, NULL);
 }
 
 enum connect_result
-tcp_socket_state(int fd, thread * thread_obj, uint32_t addr_ip, uint16_t addr_port,
-		 int (*func) (struct _thread *))
+tcp_socket_state(int fd, thread_t * thread, int (*func) (thread_t *))
 {
 	int status;
-	socklen_t slen;
+	socklen_t addrlen;
 	int ret = 0;
 	TIMEVAL timer_min;
 
 	/* Handle connection timeout */
-	if (thread_obj->type == THREAD_WRITE_TIMEOUT) {
-		DBG("TCP connection timeout to [%s:%d].",
-		    inet_ntop2(addr_ip), ntohs(addr_port));
-		close(thread_obj->u.fd);
+	if (thread->type == THREAD_WRITE_TIMEOUT) {
+		close(thread->u.fd);
 		return connect_timeout;
 	}
 
 	/* Check file descriptor */
-	slen = sizeof (status);
-	if (getsockopt
-	    (thread_obj->u.fd, SOL_SOCKET, SO_ERROR, (void *) &status, &slen) < 0)
+	addrlen = sizeof(status);
+	if (getsockopt(thread->u.fd, SOL_SOCKET, SO_ERROR, (void *) &status, &addrlen) < 0)
 		ret = errno;
 
 	/* Connection failed !!! */
 	if (ret) {
-		DBG("TCP connection failed to [%s:%d].",
-		    inet_ntop2(addr_ip), ntohs(addr_port));
-		close(thread_obj->u.fd);
+		close(thread->u.fd);
 		return connect_error;
 	}
 
@@ -123,15 +107,12 @@ tcp_socket_state(int fd, thread * thread_obj, uint32_t addr_ip, uint16_t addr_po
 	 * Recompute the write timeout (or pending connection).
 	 */
 	if (status == EINPROGRESS) {
-		DBG("TCP connection to [%s:%d] still IN_PROGRESS.",
-		    inet_ntop2(addr_ip), ntohs(addr_port));
-
-		timer_min = timer_sub_now(thread_obj->sands);
-		thread_add_write(thread_obj->master, func, THREAD_ARG(thread_obj)
-				 , thread_obj->u.fd, TIMER_LONG(timer_min));
+		timer_min = timer_sub_now(thread->sands);
+		thread_add_write(thread->master, func, THREAD_ARG(thread),
+				 thread->u.fd, TIMER_LONG(timer_min));
 		return connect_in_progress;
 	} else if (status != 0) {
-		close(thread_obj->u.fd);
+		close(thread->u.fd);
 		return connect_error;
 	}
 
@@ -139,35 +120,25 @@ tcp_socket_state(int fd, thread * thread_obj, uint32_t addr_ip, uint16_t addr_po
 }
 
 void
-tcp_connection_state(int fd, enum connect_result status, thread * thread_obj,
-		     int (*func) (struct _thread *)
-		     , long timeout)
+tcp_connection_state(int fd, enum connect_result status, thread_t * thread,
+		     int (*func) (thread_t *), long timeout)
 {
-	checker *checker_obj;
+	checker_t *checker;
 
-	checker_obj = THREAD_ARG(thread_obj);
+	checker = THREAD_ARG(thread);
 
 	switch (status) {
 	case connect_error:
-		DBG("TCP connection ERROR to [%s:%d].",
-		    inet_ntop2(SVR_IP(checker_obj->rs)),
-		    ntohs(SVR_PORT(checker_obj->rs)));
 		close(fd);
 		break;
 
 	case connect_success:
-		DBG("TCP connection SUCCESS to [%s:%d].",
-		    inet_ntop2(SVR_IP(checker_obj->rs)),
-		    ntohs(SVR_PORT(checker_obj->rs)));
-		thread_add_write(thread_obj->master, func, checker_obj, fd, timeout);
+		thread_add_write(thread->master, func, checker, fd, timeout);
 		break;
 
 		/* Checking non-blocking connect, we wait until socket is writable */
 	case connect_in_progress:
-		DBG("TCP connection to [%s:%d] now IN_PROGRESS.",
-		    inet_ntop2(SVR_IP(checker_obj->rs)),
-		    ntohs(SVR_PORT(checker_obj->rs)));
-		thread_add_write(thread_obj->master, func, checker_obj, fd, timeout);
+		thread_add_write(thread->master, func, checker, fd, timeout);
 		break;
 
 	default:
