@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _CHECK_DATA_H
@@ -32,8 +32,12 @@
 #include <openssl/ssl.h>
 
 #ifdef _WITH_LVS_
+  #ifdef _KRNL_2_4_
+    #include <net/ip_vs.h>
+  #elif _KRNL_2_6_
+    #include "../libipvs-2.6/ip_vs.h"
+  #endif
   #define SCHED_MAX_LENGTH IP_VS_SCHEDNAME_MAXLEN
-  #include <net/ip_vs.h>
 #else
   #define SCHED_MAX_LENGTH   1
 #endif
@@ -65,9 +69,9 @@ typedef struct _ssl_data {
 
 /* Real Server definition */
 typedef struct _real_server {
-	uint32_t addr_ip;
-	uint16_t addr_port;
+	struct sockaddr_storage	addr;
 	int weight;
+	int iweight;		/* Initial weight */
 #ifdef _KRNL_2_6_
 	uint32_t u_threshold;   /* Upper connection limit. */
 	uint32_t l_threshold;   /* Lower connection limit. */
@@ -84,10 +88,9 @@ typedef struct _real_server {
 
 /* Virtual Server group definition */
 typedef struct _virtual_server_group_entry {
-	uint32_t addr_ip;
+	struct sockaddr_storage	addr;
 	uint8_t range;
 	uint32_t vfwmark;
-	uint16_t addr_port;
 	int alive;
 } virtual_server_group_entry;
 
@@ -101,8 +104,8 @@ typedef struct _virtual_server_group {
 /* Virtual Server definition */
 typedef struct _virtual_server {
 	char *vsgname;
-	uint32_t addr_ip;
-	uint16_t addr_port;
+	struct sockaddr_storage	addr;
+	real_server *s_svr;
 	uint32_t vfwmark;
 	uint16_t service_type;
 	long delay_loop;
@@ -113,14 +116,14 @@ typedef struct _virtual_server {
 	uint32_t nat_mask;
 	uint32_t granularity_persistence;
 	char *virtualhost;
-	real_server *s_svr;
 	list rs;
 	int alive;
 	unsigned alpha;			/* Alpha mode enabled. */
 	unsigned omega;			/* Omega mode enabled. */
-	char * quorum_up;		/* A hook to call when the VS gains quorum. */
+	char *quorum_up;		/* A hook to call when the VS gains quorum. */
 	char * quorum_down;		/* A hook to call when the VS loses quorum. */
 	long unsigned quorum;		/* Minimum live RSs to consider VS up. */
+
 	long unsigned hysteresis;	/* up/down events "lag" WRT quorum. */
 	unsigned quorum_state;		/* Reflects result of the last transition done. */
 } virtual_server;
@@ -132,35 +135,85 @@ typedef struct _check_conf_data {
 	list vs;
 } check_conf_data;
 
+/* inline stuff */
+static inline int __ip6_addr_equal(const struct in6_addr *a1,
+				   const struct in6_addr *a2)
+{
+	return (((a1->s6_addr32[0] ^ a2->s6_addr32[0]) |
+		 (a1->s6_addr32[1] ^ a2->s6_addr32[1]) |
+		 (a1->s6_addr32[2] ^ a2->s6_addr32[2]) |
+		 (a1->s6_addr32[3] ^ a2->s6_addr32[3])) == 0);
+}
+
+static inline int sockstorage_equal(const struct sockaddr_storage *s1,
+				    const struct sockaddr_storage *s2)
+{
+	if (s1->ss_family != s2->ss_family)
+		return 0;
+
+	if (s1->ss_family == AF_INET6) {
+		struct sockaddr_in6 *a1 = (struct sockaddr_in6 *) s1;
+		struct sockaddr_in6 *a2 = (struct sockaddr_in6 *) s2;
+
+//		if (IN6_ARE_ADDR_EQUAL(a1, a2) && (a1->sin6_port == a2->sin6_port))
+		if (__ip6_addr_equal(&a1->sin6_addr, &a2->sin6_addr) &&
+		    (a1->sin6_port == a2->sin6_port))
+			return 1;
+	} else if (s1->ss_family == AF_INET) {
+		struct sockaddr_in *a1 = (struct sockaddr_in *) s1;
+		struct sockaddr_in *a2 = (struct sockaddr_in *) s2;
+
+		if ((a1->sin_addr.s_addr == a1->sin_addr.s_addr) &&
+		    (a1->sin_port == a2->sin_port))
+			return 1;
+	}
+
+	return 0;
+}
+
+static inline int inaddr_equal(sa_family_t family, void *addr1, void *addr2)
+{
+	if (family == AF_INET6) {
+		struct in6_addr *a1 = (struct in6_addr *) addr1;
+		struct in6_addr *a2 = (struct in6_addr *) addr2;
+
+		if (__ip6_addr_equal(a1, a2))
+			return 1;
+	} else if (family == AF_INET) {
+		struct in_addr *a1 = (struct in_addr *) addr1;
+		struct in_addr *a2 = (struct in_addr *) addr2;
+
+		if (a1->s_addr == a2->s_addr)
+			return 1;
+	}
+
+	return 0;
+}
+
 /* macro utility */
 #define ISALIVE(S)	((S)->alive)
 #define SET_ALIVE(S)	((S)->alive = 1)
 #define UNSET_ALIVE(S)	((S)->alive = 0)
-#define SVR_IP(H)	((H)->addr_ip)
-#define SVR_PORT(H)	((H)->addr_port)
 #define VHOST(V)	((V)->virtualhost)
 
-#define VS_ISEQ(X,Y)	((X)->addr_ip                 == (Y)->addr_ip &&		\
-			 (X)->addr_port               == (Y)->addr_port &&		\
-			 (X)->vfwmark                 == (Y)->vfwmark &&		\
-			 (X)->service_type            == (Y)->service_type &&		\
-			 (X)->loadbalancing_kind      == (Y)->loadbalancing_kind &&	\
-			 (X)->nat_mask                == (Y)->nat_mask &&		\
-			 (X)->granularity_persistence == (Y)->granularity_persistence &&\
-			 !strcmp((X)->sched, (Y)->sched) &&				\
-			 !strcmp((X)->timeout_persistence, (Y)->timeout_persistence) && \
+#define VS_ISEQ(X,Y)	(sockstorage_equal(&(X)->addr,&(Y)->addr)			&&\
+			 (X)->vfwmark                 == (Y)->vfwmark			&&\
+			 (X)->service_type            == (Y)->service_type		&&\
+			 (X)->loadbalancing_kind      == (Y)->loadbalancing_kind	&&\
+			 (X)->nat_mask                == (Y)->nat_mask			&&\
+			 (X)->granularity_persistence == (Y)->granularity_persistence	&&\
+			 !strcmp((X)->sched, (Y)->sched)				&&\
+			 !strcmp((X)->timeout_persistence, (Y)->timeout_persistence)	&&\
 			 (((X)->vsgname && (Y)->vsgname &&				\
 			   !strcmp((X)->vsgname, (Y)->vsgname)) || 			\
 			  (!(X)->vsgname && !(Y)->vsgname)))
 
-#define VSGE_ISEQ(X,Y)	((X)->addr_ip   == (Y)->addr_ip &&	\
-			 (X)->range     == (Y)->range &&	\
-			 (X)->vfwmark   == (Y)->vfwmark &&	\
-			 (X)->addr_port == (Y)->addr_port)
+#define VSGE_ISEQ(X,Y)	(sockstorage_equal(&(X)->addr,&(Y)->addr) &&	\
+			 (X)->range     == (Y)->range &&		\
+			 (X)->vfwmark   == (Y)->vfwmark)
 
-#define RS_ISEQ(X,Y)	((X)->addr_ip   == (Y)->addr_ip &&	\
-			 (X)->addr_port == (Y)->addr_port &&	\
-			 (X)->weight    == (Y)->weight)
+#define RS_ISEQ(X,Y)	(sockstorage_equal(&(X)->addr,&(Y)->addr) &&	\
+			 (X)->iweight   == (Y)->iweight)
 
 /* Global vars exported */
 extern check_conf_data *check_data;
@@ -169,16 +222,16 @@ extern check_conf_data *old_check_data;
 /* prototypes */
 extern SSL_DATA *alloc_ssl(void);
 extern void free_ssl(void);
-extern void alloc_vsg(char *gname);
-extern void alloc_vsg_entry(vector strvec);
-extern void alloc_vs(char *ip, char *port);
-extern void alloc_rs(char *ip, char *port);
-extern void alloc_ssvr(char *ip, char *port);
-extern void alloc_group(char *name);
-extern void alloc_rsgroup(char *ip, char *port);
-extern void set_rsgroup(char *gname);
+extern void alloc_vsg(char *);
+extern void alloc_vsg_entry(vector);
+extern void alloc_vs(char *, char *);
+extern void alloc_rs(char *, char *);
+extern void alloc_ssvr(char *, char *);
+extern void alloc_group(char *);
+extern void alloc_rsgroup(char *, char *);
+extern void set_rsgroup(char *);
 extern check_conf_data *alloc_check_data(void);
-extern void free_check_data(check_conf_data * check_data_obj);
-extern void dump_check_data(check_conf_data * check_data_obj);
+extern void free_check_data(check_conf_data *);
+extern void dump_check_data(check_conf_data *);
 
 #endif
