@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _CHECK_HTTP_H
@@ -38,7 +38,7 @@
 
 /* Checker argument structure  */
 /* ssl specific thread arguments defs */
-typedef struct {
+typedef struct _request {
 	char *buffer;
 	char *extracted;
 	int error;
@@ -47,30 +47,31 @@ typedef struct {
 	SSL *ssl;
 	BIO *bio;
 	MD5_CTX context;
-} REQ;
+} request_t;
 
 /* http specific thread arguments defs */
 typedef struct _http_arg {
 	int retry_it;		/* current number of get retry */
 	int url_it;		/* current url checked index */
-	REQ *req;		/* GET buffer and SSL args */
-} http_arg;
+	request_t *req;		/* GET buffer and SSL args */
+} http_arg_t ;
 
 typedef struct _url {
 	char *path;
 	char *digest;
 	int status_code;
-} url;
-typedef struct _http_get_checker {
+} url_t;
+
+typedef struct _http_checker {
 	int proto;
-	uint16_t connection_port;
-	uint32_t bindto;
+	struct sockaddr_storage dst;
+	struct sockaddr_storage bindto;
 	long connection_to;
 	int nb_get_retry;
 	long delay_before_retry;
 	list url;
-	http_arg *arg;
-} http_get_checker;
+	http_arg_t *arg;
+} http_checker_t;
 
 /* global defs */
 #define MD5_BUFFER_LENGTH 32
@@ -89,10 +90,10 @@ typedef struct _http_get_checker {
 
 /* Define prototypes */
 extern void install_http_check_keyword(void);
-extern int epilog(thread * thread_obj, int metod, int t, int c);
-extern int timeout_epilog(thread * thread_obj, char *smtp_msg, char *debug_msg);
-extern url *fetch_next_url(http_get_checker * http_get_check);
-extern int http_process_response(REQ * req, int r);
-extern int http_handle_response(thread * thread_obj, unsigned char digest[16]
-				, int empty_buffer);
+extern int epilog(thread_t *, int, int, int);
+extern int timeout_epilog(thread_t *, char *, char *);
+extern url_t *fetch_next_url(http_checker_t *);
+extern int http_process_response(request_t *, int);
+extern int http_handle_response(thread_t *, unsigned char digest[16]
+				, int);
 #endif
