@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _CHECK_SMTP_H
@@ -46,10 +46,9 @@
 
 /* Per host configuration structure  */
 typedef struct _smtp_host {
-	uint16_t port;
-	uint32_t ip;
-	uint32_t bindto;
-} smtp_host;
+	struct sockaddr_storage dst;
+	struct sockaddr_storage bindto;
+} smtp_host_t;
 
 /* Checker argument structure  */
 typedef struct _smtp_checker {
@@ -60,18 +59,18 @@ typedef struct _smtp_checker {
 	int retry;
 	int attempts;
 	int  host_ctr;
-	smtp_host *host_ptr;
+	smtp_host_t *host_ptr;
 
 	/* data buffer */
 	char buff[SMTP_BUFF_MAX];
 	int buff_ctr;
-	int (*buff_cb) (struct _thread *);
+	int (*buff_cb) (thread_t *);
 
 	int state;
 
 	/* list holding the host config data */
 	list host;
-} smtp_checker;
+} smtp_checker_t;
 
 /* Prototypes defs */
 extern void install_smtp_check_keyword(void);
