@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _CHECK_SSL_H
@@ -30,10 +30,10 @@
 /* Prototypes */
 extern void install_ssl_check_keyword(void);
 extern int init_ssl_ctx(void);
-extern void clear_ssl(SSL_DATA * ssl);
-extern int ssl_connect(thread * thread_obj, int new_req);
-extern int ssl_printerr(int err);
-extern int ssl_send_request(SSL * ssl, char *str_request, int request_len);
-extern int ssl_read_thread(thread * thread_obj);
+extern void clear_ssl(SSL_DATA *);
+extern int ssl_connect(thread_t *, int);
+extern int ssl_printerr(int);
+extern int ssl_send_request(SSL *, char *, int);
+extern int ssl_read_thread(thread_t *);
 
 #endif
