@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _IPVSWRAPPER_H
@@ -40,10 +40,12 @@
 #ifdef _WITH_LVS_
 #ifdef _KRNL_2_4_
   #include "../libipvs-2.4/libipvs.h"
+  #include <net/ip_vs.h>
 #elif _KRNL_2_6_
+  #include "../libipvs-2.6/ip_vs.h"
   #include "../libipvs-2.6/libipvs.h"
 #endif
-  #include <net/ip_vs.h>
+//  #include <net/ip_vs.h>
 #endif
 
 #ifndef IP_VS_TEMPLATE_TIMEOUT
@@ -89,13 +91,11 @@ do {						\
 /* prototypes */
 extern int ipvs_start(void);
 extern void ipvs_stop(void);
-extern virtual_server_group *ipvs_get_group_by_name(char *gname, list l);
-extern int ipvs_group_remove_entry(virtual_server * vs,
-				   virtual_server_group_entry * vsge);
-extern int ipvs_cmd(int cmd, list vs_group, virtual_server * vserver,
-		    real_server * rserver);
-extern int ipvs_syncd_cmd(int cmd, char *ifname, int state, int syncid);
-extern void ipvs_syncd_master(char *ifname, int syncid);
-extern void ipvs_syncd_backup(char *ifname, int syncid);
+extern virtual_server_group *ipvs_get_group_by_name(char *, list);
+extern int ipvs_group_remove_entry(virtual_server *, virtual_server_group_entry *);
+extern int ipvs_cmd(int, list, virtual_server *, real_server *);
+extern int ipvs_syncd_cmd(int, char *, int, int);
+extern void ipvs_syncd_master(char *, int);
+extern void ipvs_syncd_backup(char *, int);
 
 #endif
