@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_DATA_H
@@ -39,12 +39,13 @@
  * That way we handle VRRP protocol type per
  * physical interface.
  */
-typedef struct {
-	int ifindex;
+typedef struct _sock {
+	sa_family_t family;
 	int proto;
+	int ifindex;
 	int fd_in;
 	int fd_out;
-} sock;
+} sock_t;
 
 /* Configuration data root */
 typedef struct _vrrp_conf_data {
@@ -64,21 +65,21 @@ extern vrrp_conf_data *old_vrrp_data;
 extern char *vrrp_buffer;
 
 /* prototypes */
-extern void alloc_saddress(vector strvec);
-extern void alloc_sroute(vector strvec);
-extern void alloc_vrrp_sync_group(char *gname);
-extern void alloc_vrrp(char *iname);
-extern void alloc_vrrp_track(vector strvec);
-extern void alloc_vrrp_script(char *sname);
-extern void alloc_vrrp_track_script(vector strvec);
-extern void alloc_vrrp_vip(vector strvec);
-extern void alloc_vrrp_evip(vector strvec);
-extern void alloc_vrrp_vroute(vector strvec);
+extern void alloc_saddress(vector);
+extern void alloc_sroute(vector);
+extern void alloc_vrrp_sync_group(char *);
+extern void alloc_vrrp(char *);
+extern void alloc_vrrp_track(vector);
+extern void alloc_vrrp_script(char *);
+extern void alloc_vrrp_track_script(vector);
+extern void alloc_vrrp_vip(vector);
+extern void alloc_vrrp_evip(vector);
+extern void alloc_vrrp_vroute(vector);
 extern void alloc_vrrp_buffer(void);
 extern void free_vrrp_buffer(void);
 extern vrrp_conf_data *alloc_vrrp_data(void);
-extern void free_vrrp_data(vrrp_conf_data * vrrp_data_obj);
-extern void dump_vrrp_data(vrrp_conf_data * vrrp_data_obj);
-extern void free_vrrp_sockpool(vrrp_conf_data * vrrp_data_obj);
+extern void free_vrrp_data(vrrp_conf_data *);
+extern void dump_vrrp_data(vrrp_conf_data *);
+extern void free_vrrp_sockpool(vrrp_conf_data *);
 
 #endif
