@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_INDEX_H
@@ -36,10 +36,10 @@
 /* Macro definition */
 
 /* prototypes */
-extern void alloc_vrrp_bucket(vrrp_rt *vrrp);
-extern void alloc_vrrp_fd_bucket(vrrp_rt *vrrp);
-extern void remove_vrrp_fd_bucket(vrrp_rt *vrrp);
-extern void set_vrrp_fd_bucket(int old_fd, vrrp_rt *vrrp);
-extern vrrp_rt *vrrp_index_lookup(const int vrid, const int fd);
+extern void alloc_vrrp_bucket(vrrp_rt *);
+extern void alloc_vrrp_fd_bucket(vrrp_rt *);
+extern void remove_vrrp_fd_bucket(vrrp_rt *);
+extern void set_vrrp_fd_bucket(int, vrrp_rt *);
+extern vrrp_rt *vrrp_index_lookup(const int, const int);
 
 #endif
