@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_SCHEDULER_H
@@ -58,8 +58,8 @@ do {						\
 } while (0)
 
 /* extern prototypes */
-extern void vrrp_dispatcher_release(vrrp_conf_data * conf_data_obj);
-extern int vrrp_dispatcher_init(thread * thread_obj);
-extern int vrrp_read_dispatcher_thread(thread * thread_obj);
+extern void vrrp_dispatcher_release(vrrp_conf_data *);
+extern int vrrp_dispatcher_init(thread_t *);
+extern int vrrp_read_dispatcher_thread(thread_t *);
 
 #endif
