@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 /* global include */
@@ -146,7 +146,7 @@ netlink_set_nonblock(struct nl_handle *nl, int *flags)
 
 /* iproute2 utility function */
 int
-addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data_obj)
+addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data)
 {
 	int len = RTA_LENGTH(4);
 	struct rtattr *rta;
@@ -155,13 +155,13 @@ addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data_obj)
 	rta = (struct rtattr*)(((char*)n) + NLMSG_ALIGN(n->nlmsg_len));
 	rta->rta_type = type;
 	rta->rta_len = len;
-	memcpy(RTA_DATA(rta), &data_obj, 4);
+	memcpy(RTA_DATA(rta), &data, 4);
 	n->nlmsg_len = NLMSG_ALIGN(n->nlmsg_len) + len;
 	return 0;
 }
 
 int
-addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data_obj, int alen)
+addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data, int alen)
 {
 	int len = RTA_LENGTH(alen);
 	struct rtattr *rta;
@@ -172,7 +172,7 @@ addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data_obj, int alen)
 	rta = (struct rtattr *) (((char *) n) + NLMSG_ALIGN(n->nlmsg_len));
 	rta->rta_type = type;
 	rta->rta_len = len;
-	memcpy(RTA_DATA(rta), data_obj, alen);
+	memcpy(RTA_DATA(rta), data, alen);
 	n->nlmsg_len = NLMSG_ALIGN(n->nlmsg_len) + len;
 
 	return 0;
@@ -498,13 +498,13 @@ netlink_if_address_filter(struct sockaddr_nl *snl, struct nlmsghdr *h)
 	struct ifaddrmsg *ifa;
 	struct rtattr *tb[IFA_MAX + 1];
 	interface *ifp;
-	uint32_t address = 0;
 	int len;
+	void *addr;
 
 	ifa = NLMSG_DATA(h);
 
 	/* Only IPV4 are valid us */
-	if (ifa->ifa_family != AF_INET)
+	if (ifa->ifa_family != AF_INET && ifa->ifa_family != AF_INET6)
 		return 0;
 
 	if (h->nlmsg_type != RTM_NEWADDR && h->nlmsg_type != RTM_DELADDR)
@@ -521,28 +521,31 @@ netlink_if_address_filter(struct sockaddr_nl *snl, struct nlmsghdr *h)
 	ifp = if_get_by_ifindex(ifa->ifa_index);
 	if (!ifp)
 		return 0;
-
+	if (tb[IFA_LOCAL] == NULL)
+		tb[IFA_LOCAL] = tb[IFA_ADDRESS];
 	if (tb[IFA_ADDRESS] == NULL)
 		tb[IFA_ADDRESS] = tb[IFA_LOCAL];
 
-	if (ifp->flags & IFF_POINTOPOINT) {
-		if (tb[IFA_LOCAL])
-			address = *(uint32_t *) RTA_DATA(tb[IFA_LOCAL]);
-	} else {
-		if (tb[IFA_ADDRESS])
-			address = *(uint32_t *) RTA_DATA(tb[IFA_ADDRESS]);
-	}
+	/* local interface address */
+	addr = (tb[IFA_LOCAL] ? RTA_DATA(tb[IFA_LOCAL]) : NULL);
+
+	if (addr == NULL)
+		return -1;
 
 	/* If no address is set on interface then set the first time */
-	if (!ifp->address)
-		ifp->address = address;
+	if (ifa->ifa_family == AF_INET) {
+		if (!ifp->sin_addr.s_addr)
+			ifp->sin_addr = *(struct in_addr *) addr;
+	} else {
+		if (!ifp->sin6_addr.s6_addr16[0] && ifa->ifa_scope == RT_SCOPE_LINK)
+			ifp->sin6_addr = *(struct in6_addr *) addr;
+	}
 
 #ifdef _WITH_LVS_
 	/* Refresh checkers state */
-	update_checker_activity(address,
+	update_checker_activity(ifa->ifa_family, addr,
 				(h->nlmsg_type == RTM_NEWADDR) ? 1 : 0);
 #endif
-
 	return 0;
 }
 
@@ -589,16 +592,23 @@ netlink_address_lookup(void)
 	/* Set blocking flag */
 	ret = netlink_set_block(&nlh, &flags);
 	if (ret < 0)
-		log_message(LOG_INFO, "Netlink: 2Warning, couldn't set "
+		log_message(LOG_INFO, "Netlink: Warning, couldn't set "
 		       "blocking flag to netlink socket...");
 
-	/* Address lookup */
+	/* IPv4 Address lookup */
 	if (netlink_request(&nlh, AF_INET, RTM_GETADDR) < 0) {
 		status = -1;
 		goto end_addr;
 	}
 	status = netlink_parse_info(netlink_if_address_filter, &nlh, NULL);
 
+	/* IPv6 Address lookup */
+	if (netlink_request(&nlh, AF_INET6, RTM_GETADDR) < 0) {
+		status = -1;
+		goto end_addr;
+	}
+	status = netlink_parse_info(netlink_if_address_filter, &nlh, NULL);
+
 end_addr:
 	netlink_close(&nlh);
 	return status;
@@ -665,11 +675,11 @@ netlink_broadcast_filter(struct sockaddr_nl *snl, struct nlmsghdr *h)
 }
 
 int
-kernel_netlink(thread * thread_obj)
+kernel_netlink(thread_t * thread)
 {
 	int status = 0;
 
-	if (thread_obj->type != THREAD_READ_TIMEOUT)
+	if (thread->type != THREAD_READ_TIMEOUT)
 		status = netlink_parse_info(netlink_broadcast_filter, &nl_kernel, NULL);
 	thread_add_read(master, kernel_netlink, NULL, nl_kernel.fd,
 			NETLINK_TIMER);
@@ -689,7 +699,7 @@ kernel_netlink_init(void)
 	 * subscribtion. We subscribe to LINK and ADDR
 	 * netlink broadcast messages.
 	 */
-	groups = RTMGRP_LINK | RTMGRP_IPV4_IFADDR;
+	groups = RTMGRP_LINK | RTMGRP_IPV4_IFADDR | RTMGRP_IPV6_IFADDR;
 	netlink_socket(&nl_kernel, groups);
 
 	if (nl_kernel.fd > 0) {
