@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _UTILS_H
@@ -45,15 +45,21 @@
 extern int debug;
 
 /* Prototypes defs */
-extern void dump_buffer(char *buff, int count);
-extern u_short in_csum(u_short * addr, int len, u_short csum);
-extern char *inet_ntop2(uint32_t ip);
-extern char *inet_ntoa2(uint32_t ip, char *buf);
-extern uint8_t inet_stom(char *addr);
-extern uint8_t inet_stor(char *addr);
-extern int inet_ston(const char *addr, uint32_t *dst);
-uint32_t inet_broadcast(uint32_t network, uint32_t netmask);
-uint32_t inet_cidrtomask(uint8_t cidr);
+extern void dump_buffer(char *, int);
+extern u_short in_csum(u_short *, int, u_short);
+extern char *inet_ntop2(uint32_t);
+extern char *inet_ntoa2(uint32_t, char *);
+extern uint8_t inet_stom(char *);
+extern uint8_t inet_stor(char *);
+extern int inet_stosockaddr(char *, char *, struct sockaddr_storage *);
+extern char *inet_sockaddrtos(struct sockaddr_storage *);
+extern char *inet_sockaddrtos2(struct sockaddr_storage *, char *);
+extern uint16_t inet_sockaddrport(struct sockaddr_storage *);
+extern uint32_t inet_sockaddrip4(struct sockaddr_storage *);
+extern int inet_sockaddrip6(struct sockaddr_storage *, struct in6_addr *);
+extern int inet_ston(const char *, uint32_t *);
+uint32_t inet_broadcast(uint32_t, uint32_t);
+uint32_t inet_cidrtomask(uint8_t);
 extern char *get_local_name(void);
 
 #endif
